@@ -62,7 +62,7 @@ enum e_options {
  */
 static const char *s_opts[] = {
     "category", "orientation", "editors_choice", "safesearch", "order",
-    "min_width", "min_height", "per_page", "colors"
+    "min_width", "min_height", "per_page", "colors", NULL
 };
 /*----------------------------------------------------------------------------*/
 /**
@@ -73,7 +73,8 @@ static const char *s_category[] = {
     "none", "backgrounds", "fashion", "nature", "science", "education",
     "feelings", "health", "people", "religion", "places", "animals",
     "industry", "computer", "food", "sports", "transportation", "travel",
-    "buildings", "business", "music", NULL};
+    "buildings", "business", "music", NULL
+};
 /*----------------------------------------------------------------------------*/
 /**
  * @var   s_colour
@@ -82,7 +83,8 @@ static const char *s_category[] = {
 static const char *s_colour[] = {
     "any", "grayscale", "transparent", "red", "orange", "yellow", "green",
     "turquoise", "blue", "lilac", "pink", "white", "gray", "black",
-    "brown", NULL};
+    "brown", NULL
+};
 /*----------------------------------------------------------------------------*/
 /**
  * @var   s_true_false
@@ -352,15 +354,15 @@ pixbay_json_to_webwidget (const char  *s_buff,
  * @brief  Search in Pexels database.
  */
 void
-pixbay_search (WebWidget         *ww_widget,
-               const FourStrings *fs_data)
+pixbay_search (WebWidget      *ww_widget,
+               const NStrings *ns_data)
 {
     UrlData    *ud_data      = NULL; /* For search results */
     CacheQuery *cq_query     = NULL; /* For cache saving */
     char       *s_query      = NULL; /* For search query */
     int         i_err        = 0;    /* Error output */
 
-    if (str_is_empty_msg (fs_data->s_str1, "Pixbay API key is not set"))
+    if (str_is_empty_msg (ns_data->s_str[0], "Pixbay API key is not set"))
         return;
 
     s_query = str_replace_in (ww_widget->s_query, " ", "+");
@@ -372,7 +374,7 @@ pixbay_search (WebWidget         *ww_widget,
 
     ud_data = urldata_search_pixbay (s_query,
                                      ww_widget->s_search_opts,
-                                     fs_data->s_str1,
+                                     ns_data->s_str[0],
                                      ww_widget->i_page);
     if (ud_data->errbuf != NULL) {
         message_dialog_error (NULL, ud_data->errbuf);
@@ -405,7 +407,7 @@ pixbay_search (WebWidget         *ww_widget,
  * @brief  Dialog with Pixbay service settings.
  */
 int
-pixbay_settings_dialog (FourStrings *fs_data)
+pixbay_settings_dialog (NStrings *ns_data)
 {
     GtkWidget *gw_dialog;      /* Pixbay settings dialog */
     GtkWidget *gw_content_box; /* Dialog's box */
@@ -428,7 +430,7 @@ pixbay_settings_dialog (FourStrings *fs_data)
 
     gw_api_entry = gtk_entry_new ();
 
-    gtk_entry_set_text (GTK_ENTRY (gw_api_entry), fs_data->s_str1);
+    gtk_entry_set_text (GTK_ENTRY (gw_api_entry), ns_data->s_str[0]);
 
     /* Packing dialog widgets */
     gtk_box_pack_start (GTK_BOX (gw_content_box),
@@ -460,8 +462,8 @@ pixbay_settings_dialog (FourStrings *fs_data)
     i_res = gtk_dialog_run (GTK_DIALOG (gw_dialog));
 
     if (i_res == GTK_RESPONSE_ACCEPT) {
-        free (fs_data->s_str1);
-        fs_data->s_str1 = strdup (
+        free (ns_data->s_str[0]);
+        ns_data->s_str[0] = strdup (
                 gtk_entry_get_text (GTK_ENTRY (gw_api_entry)));
     }
     gtk_widget_destroy (gw_dialog);
